KeystoneSolSignRequest class

Constructors

KeystoneSolSignRequest({Uint8List? requestId, required Uint8List signData, required SignType signType, required CryptoKeypath derivationPath, Uint8List? addressBytes, String? origin})

Properties

addressBytes Uint8List?
final
derivationPath → CryptoKeypath
final
hashCode int
The hash code for this object.
no setterinherited
origin String?
final
requestId Uint8List?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signData Uint8List
final
signType SignType
final

Methods

buildCbor() Map<int, CborValue>
路径 A(扁平结构推荐): override buildCbor() 填入字段 基类 toCborValue() 自动组装成 CborMap
inherited
cborBigInt(BigInt value) CborValue
支持 BigInt 编码(用于 chain-id 等大整数场景)
inherited
cborBytes(Uint8List data, {List<int>? tags}) CborBytes
inherited
cborInt(int value) CborValue
inherited
decodeFromCbor(CborMap map) → RegistryItem
getRegistryType() RegistryType
getRequestId() Uint8List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCBOR() Uint8List
inherited
toCborValue() CborValue
统一编码入口
toString() String
A string representation of this object.
override
toUR() UR
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

buildMessageRequest({required String messageHex, required String path, required String xfp, String? address, String? origin, Uint8List? uuid}) UR
构造消息签名请求 QR,显示给 Keystone 扫描
buildTransactionRequest({required String txHex, required String path, required String xfp, String? address, String? origin, Uint8List? uuid}) UR
构造一笔链上交易签名请求 QR,显示给 Keystone 扫描
fromUR(UR ur) KeystoneSolSignRequest
解析 Keystone 设备扫回的 sol-sign-request UR