SolSignRequest class

Constructors

SolSignRequest({Uint8List? uuid, required Uint8List signData, required SignType signType, required CryptoKeypath derivationPath, String? outputAddress, String? contractAddress, String? origin, int? fee})

Properties

contractAddress String?
final
derivationPath → CryptoKeypath
final
fee int?
final
hashCode int
The hash code for this object.
no setterinherited
origin String?
final
outputAddress String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signData Uint8List
final
signType SignType
final
uuid Uint8List?
getter/setter pair

Methods

buildCbor() Map<int, CborValue>
路径 A(扁平结构推荐): override buildCbor() 填入字段 基类 toCborValue() 自动组装成 CborMap
inherited
cborBigInt(BigInt value) CborValue
支持 BigInt 编码(用于 chain-id 等大整数场景)
inherited
cborBytes(Uint8List data, {List<int>? tags}) CborBytes
inherited
cborInt(int value) CborValue
inherited
decodeFromCbor(CborMap map) → RegistryItem
getDerivationPath() String?
getRegistryType() RegistryType
getRequestId() Uint8List
getSourceFingerprint() Uint8List?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCBOR() Uint8List
inherited
toCborValue() CborValue
统一编码入口
toString() String
A string representation of this object.
inherited
toUR() UR
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromCBOR(Uint8List cborPayload) SolSignRequest
generateSignRequest({String? uuid, required String signData, required SignType signType, required String path, required String xfp, String? outputAddress, String? contractAddress, String? origin, int? fee}) UR